#[test]Expand description
Defines a test to be executed on a Game Boy Advance.
Example
#[ktest_macros::test]
fn foo() {
assert!(true);
}The test macro supports the other testing attributes you would expect to use when writing unit
tests in Rust. Specifically, the #[ignore] and #[should_panic] attributes are supported.
Example
#[ktest_macros::test]
#[ignore]
fn ignored() {
assert!(false);
}
#[ktest_macros::test]
#[should_panic]
fn panics() {
panic!("expected panic");
}